django-affiliate release notes
==============================

v0.2.1 (2015-10-29)
-------------------
- add translations to pypi

v0.2.0 (2015-10-29)
-------------------
- only affiliate model defined by package
- request now have lazy `affiliate` property, returns Affiliate instance (if exists)
- django 1.7, 1.8 support
- python 3.4 support
- tests are added
- backwards incompatible

Issues: #1, #3, #4, #6, #8

v0.1.1 (2015-01-15)
-------------------
- uploaded to pypi
- small bug fixes


v0.1.0 (2014-04-29)
-------------------

- affiliate model
- statistics models
- means for withdraw request
